@@ -1,22 +1,27 @@
+( cd opt/kde/share/doc/HTML/en/xsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/xsldbg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/klinkstatus ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kfilereplace ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kxsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kimagemapeditor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kimagemapeditor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/lib ; rm -rf libklinkstatuscommon.so )
 ( cd opt/kde/lib ; ln -sf libklinkstatuscommon.so.4 libklinkstatuscommon.so )
 ( cd opt/kde/lib ; rm -rf libklinkstatuscommon.so.4 )
 ( cd opt/kde/lib ; ln -sf libklinkstatuscommon.so.4.0.0 libklinkstatuscommon.so.4 )
+( cd opt/kde/lib ; rm -rf libkommandercore.so )
+( cd opt/kde/lib ; ln -sf libkommandercore.so.4 libkommandercore.so )
+( cd opt/kde/lib ; rm -rf libkommandercore.so.4 )
+( cd opt/kde/lib ; ln -sf libkommandercore.so.4.2.0 libkommandercore.so.4 )
 ( cd opt/kde/lib ; rm -rf libkommanderwidgets.so )
 ( cd opt/kde/lib ; ln -sf libkommanderwidgets.so.4 libkommanderwidgets.so )
 ( cd opt/kde/lib ; rm -rf libkommanderwidgets.so.4 )
 ( cd opt/kde/lib ; ln -sf libkommanderwidgets.so.4.2.0 libkommanderwidgets.so.4 )
-( cd opt/kde/lib ; rm -rf libkommandercore.so.4 )
-( cd opt/kde/lib ; ln -sf libkommandercore.so.4.2.0 libkommandercore.so.4 )
-( cd opt/kde/lib ; rm -rf libkommandercore.so )
-( cd opt/kde/lib ; ln -sf libkommandercore.so.4 libkommandercore.so )
-( cd opt/kde/share/doc/HTML/en/kimagemapeditor ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kimagemapeditor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/klinkstatus ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kxsldbg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/xsldbg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/xsldbg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kfilereplace ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+#%% begin initialize kdewebdev-4.3.1
+if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
+	/bin/bash /opt/kde/bin/plamo_update_kde.sh
+fi
+#%% end
